# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.5] - 2024-09-06
### Changed
- Release using different gh action

## [0.1.4] - 2024-09-06
### Added
- Publish to PyPI

## [0.1.3] - 2024-09-06
### Changed
- Fixed release CI

## [0.1.1] - 2024-09-06
### Added
- Initial release!

[Unreleased]: https://github.com/lmgarret/py-pcbu/compare/0.1.5...HEAD
[0.1.5]: https://github.com/lmgarret/py-pcbu/compare/0.1.4...0.1.5
[0.1.4]: https://github.com/lmgarret/py-pcbu/compare/0.1.3...0.1.4
[0.1.3]: https://github.com/lmgarret/py-pcbu/compare/0.1.1...0.1.3
[0.1.1]: https://github.com/lmgarret/py-pcbu/compare/7072a13019d0054e81e7d8d2ed249a9498bd4ddd...0.1.1
